/*!
 * vue-number-smarty v2.0.1
 * (c) Maxim Noverin
 * Released under the MIT License.
 */
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var __vue_normalize__ = _interopDefault(require('vue-runtime-helpers/dist/normalize-component.js'));
var __vue_create_injector__ = _interopDefault(require('vue-runtime-helpers/dist/inject-style/browser.js'));

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

var Validator =
/*#__PURE__*/
function () {
  function Validator() {
    _classCallCheck(this, Validator);
  }

  _createClass(Validator, null, [{
    key: "isLetterOrEqual",
    value: function isLetterOrEqual(n, maxValue) {
      return +n <= +maxValue;
    }
  }, {
    key: "isGreaterOrEqual",
    value: function isGreaterOrEqual(n, minValue) {
      return +n >= +minValue;
    }
  }, {
    key: "isCorrectFloat",
    value: function isCorrectFloat(n, unsigned, intPartMaxLen, floatPartMaxLen) {
      var reFloatUnsigned = new RegExp("\\d{1,".concat(intPartMaxLen, "}(\\.\\d{0,").concat(floatPartMaxLen, "})?$"), 'g');
      var reFloatSigned = new RegExp("^-?\\d{1,".concat(intPartMaxLen, "}(\\.\\d{0,").concat(floatPartMaxLen, "})?$"), 'g');
      var regExpToUse = '';

      if (unsigned) {
        regExpToUse = reFloatUnsigned;
      } else {
        regExpToUse = reFloatSigned;
      }

      var matches = String(n).match(regExpToUse);

      if (matches) {
        return String(matches[0]) === String(n);
      }

      return false;
    }
  }, {
    key: "isCorrectInteger",
    value: function isCorrectInteger(n, unsigned, maxLen) {
      var reIntegerUnsigned = new RegExp("^(\\d){1,".concat(maxLen, "}$"), 'g');
      var reIntegerSigned = new RegExp("^-?(\\d){1,".concat(maxLen, "}$"), 'g');
      var regExpToUse = '';

      if (unsigned) {
        regExpToUse = reIntegerUnsigned;
      } else {
        regExpToUse = reIntegerSigned;
      }

      var matches = String(n).match(regExpToUse);

      if (matches) {
        return String(matches[0]) === String(n);
      }

      return false;
    }
  }]);

  return Validator;
}();

//
var script = {
  name: 'VueNumberInput',
  props: {
    disabled: {
      required: false,
      type: Boolean,
      default: false
    },
    align: {
      required: false,
      type: String,
      default: 'left',
      validator: function validator(value) {
        return ['left', 'center', 'right', 'justify'].includes(value);
      }
    },
    value: {
      required: false,
      type: [Number, String],
      default: ''
    },
    placeholder: {
      required: false,
      type: String,
      default: ''
    },
    unsigned: {
      required: false,
      type: Boolean,
      default: false
    },
    numberType: {
      required: true,
      type: String,
      validator: function validator(value) {
        return ['integer', 'float'].includes(value);
      }
    },
    minValue: {
      required: false,
      type: Number,
      default: -9999999
    },
    maxValue: {
      required: false,
      type: Number,
      default: 9999999
    },
    step: {
      required: false,
      type: Number,
      default: 1
    },

    /* only for integer | max length of string */
    maxLen: {
      required: false,
      type: Number,
      default: 6
    },

    /* max length of string before float part */
    intPartMaxLen: {
      required: false,
      type: Number,
      default: 4
    },

    /* max length of string after float part */
    floatPartMaxLen: {
      required: false,
      type: Number,
      default: 2
    },
    error: {
      required: false,
      type: Boolean,
      default: false
    },
    color: {
      required: false,
      type: String,
      default: 'rgba(0,0,0,.4)'
    },
    textColor: {
      required: false,
      type: String,
      default: 'rgba(0,0,0,.9)'
    },
    fontWeight: {
      required: false,
      type: String,
      default: 'normal'
    },
    fontFamily: {
      required: false,
      type: String,
      default: 'monospace'
    },
    fontSize: {
      required: false,
      type: String,
      default: '1.3em'
    },
    maxWidth: {
      required: false,
      type: String,
      default: '250px'
    },
    margin: {
      required: false,
      type: String,
      default: '0 auto'
    },
    padding: {
      required: false,
      type: String,
      default: '5px 10px'
    }
  },
  data: function data() {
    return {
      model: String(this.value)
    };
  },
  watch: {
    value: function value(val) {
      this.model = String(val);
    },
    model: function model(val) {
      var _this = this;

      if (this.unsigned && val === '-') {
        this.$nextTick(function () {
          _this.model = '';
        });
        return false;
      }
      /* cut the string if the user manually entered too many characters */


      if (this.numberType === 'integer' && val.length > this.maxLenComputed) {
        this.$nextTick(function () {
          _this.model = val.substr(0, _this.maxLenComputed);
        });
        return false;
      }
      /* control compliance with the intPartMaxLen and floatPartMaxLen */


      if (this.numberType === 'float') {
        var intPart = val.split('.')[0];
        var floatPart = val.split('.')[1] || '';
        /* processing integer part of number */

        if (intPart.length > this.intPartMaxLenComputed) {
          intPart = intPart.slice(0, this.intPartMaxLenComputed);
          this.$nextTick(function () {
            _this.model = "".concat(intPart, ".").concat(floatPart);
          });
          return false;
        }
        /* processing float part of number */


        if (floatPart.length > this.floatPartMaxLen) {
          floatPart = floatPart.slice(0, this.floatPartMaxLen);
          this.$nextTick(function () {
            _this.model = "".concat(intPart, ".").concat(floatPart);
          });
          return false;
        }
      }

      this.$nextTick(function () {
        _this.emitValue();
      });
    }
  },
  computed: {
    inputClassesComputed: function inputClassesComputed() {
      return {
        'vue-number-input__input': true,
        'vue-number-input__input-error': this.error
      };
    },
    wrapperStylesComputed: function wrapperStylesComputed() {
      return {
        maxWidth: this.maxWidth || '300px',
        margin: this.margin || '0 auto'
      };
    },
    inputStylesComputed: function inputStylesComputed() {
      return {
        textAlign: this.align,
        borderBottomColor: this.error ? 'crimson' : this.color,
        color: this.textColor,
        fontWeight: this.fontWeight,
        fontFamily: this.fontFamily,
        fontSize: this.fontSize,
        padding: this.padding
      };
    },

    /* string max length without minus sign */
    maxLenComputed: function maxLenComputed() {
      if (this.model[0] === '-') {
        return this.maxLen + 1;
      }

      return this.maxLen;
    },

    /* integer part of string max length without minus sign */
    intPartMaxLenComputed: function intPartMaxLenComputed() {
      if (this.model[0] === '-') {
        return this.intPartMaxLen + 1;
      }

      return this.intPartMaxLen;
    }
  },
  methods: {
    /* base logic */
    emitValue: function emitValue() {
      this.$emit('input', this.model);
    },
    increment: function increment() {
      /* put decrement's result to temp variable for validation */
      var testModel = String(+this.model + this.step);
      /* reject decrement if max length exceeded */

      if (this.numberType === 'integer' && testModel.length > this.maxLenComputed) {
        return false;
      }

      if (this.numberType === 'float') {
        var intPart = testModel.split('.')[0];

        if (intPart.length > this.intPartMaxLenComputed) {
          return false;
        }
      }

      if (Validator.isLetterOrEqual(testModel, this.maxValue)) {
        /* if all is good then just increment */
        this.model = String(+this.model + this.step);
      }
    },
    decrement: function decrement() {
      /* put decrement's result to temp variable for validation */
      var testModel = String(+this.model - this.step);
      /* if the number after the decrement becomes negative */

      if (+this.model <= 0) {
        /* if the number can't be signed */
        if (this.unsigned) {
          this.model = '0';
          return false;
        }
        /* reject decrement if max length exceeded */


        if (this.numberType === 'integer' && testModel.length > this.maxLenComputed) {
          return false;
        }

        if (this.numberType === 'float') {
          var intPart = testModel.split('.')[0];

          if (intPart.length > this.intPartMaxLenComputed) {
            return false;
          }
        }
      }

      if (Validator.isGreaterOrEqual(testModel, this.minValue)) {
        /* if all is good then just decrement */
        this.model = String(+this.model - this.step);
      }
    },

    /* events */
    onBlur: function onBlur() {
      this.formatModelForEmit();
      this.emitValue();
    },
    onNumInputWheel: function onNumInputWheel(e) {
      /* only if field is focused */
      var classList = document.activeElement.classList;

      if (classList[0] && classList[0] === 'vue-number-input__input') {
        e.preventDefault();

        if (e.deltaY < 0) {
          this.increment();
        } else if (e.deltaY > 0) {
          this.decrement();
        }

        return false;
      }

      return false;
    },

    /* utils */
    formatModelForEmit: function formatModelForEmit() {
      var checkFuncName = this.numberType === 'float' ? 'isCorrectFloat' : 'isCorrectInteger';

      if (!Validator[checkFuncName](this.model, this.unsigned, this.numberType === 'float' ? this.intPartMaxLen : this.maxLen, this.floatPartMaxLen)) {
        this.model = '';
      } else {
        /* clean the line from incorrect characters */
        this.model = String(+this.model);
        /* control compliance with max and min boundaries */

        this.model = +this.model > this.maxValue ? String(this.maxValue) : this.model;
        this.model = +this.model < this.minValue ? String(this.minValue) : this.model;
      }
    }
  }
};

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "vue-number-input__wrapper",
    style: _vm.wrapperStylesComputed
  }, [_c('input', {
    directives: [{
      name: "model",
      rawName: "v-model",
      value: _vm.model,
      expression: "model"
    }],
    class: _vm.inputClassesComputed,
    style: _vm.inputStylesComputed,
    attrs: {
      "type": "text",
      "placeholder": _vm.placeholder,
      "disabled": _vm.disabled
    },
    domProps: {
      "value": _vm.model
    },
    on: {
      "wheel": function wheel($event) {
        return _vm.onNumInputWheel($event);
      },
      "blur": _vm.onBlur,
      "input": function input($event) {
        if ($event.target.composing) {
          return;
        }

        _vm.model = $event.target.value;
      }
    }
  }), _vm._v(" "), _c('div', {
    staticClass: "vue-number-input-arrows"
  }, [_c('button', {
    staticClass: "vue-number-input-arrows__arrow-up",
    on: {
      "click": _vm.increment
    }
  }), _vm._v(" "), _c('button', {
    staticClass: "vue-number-input-arrows__arrow-down",
    on: {
      "click": _vm.decrement
    }
  })])]);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = function __vue_inject_styles__(inject) {
  if (!inject) return;
  inject("data-v-3423dd36_0", {
    source: ".vue-number-input__wrapper{display:block;position:relative}.vue-number-input__wrapper .vue-number-input__input{box-sizing:border-box;width:100%;padding-right:20px!important;font-size:1rem;box-shadow:none;border:1px solid rgba(0,0,0,.1);border-bottom:2px solid rgba(128,128,128,.8);outline:0}.vue-number-input__wrapper .vue-number-input__input:focus{box-shadow:0 -1px 4px rgba(0,0,0,.1)}.vue-number-input__wrapper .vue-number-input__input-error{border-bottom-color:#dc143c;background:rgba(220,20,60,.1)}.vue-number-input__wrapper .vue-number-input-arrows{position:absolute;right:3px;top:0;bottom:3px;display:flex;flex-direction:column;padding:3px 0;min-width:13px}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-up{position:relative;background:0 0;box-shadow:none;border:none;outline:0;flex-grow:1;cursor:pointer}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-up:hover{background:rgba(0,0,0,.075)}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-up:hover:after{border-bottom-color:rgba(0,0,0,.5)}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-up:after{content:\"\";display:block;border-bottom:6px solid rgba(0,0,0,.6);border-left:4px solid transparent;border-right:4px solid transparent;width:0}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-down{position:relative;background:0 0;box-shadow:none;border:none;outline:0;flex-grow:1;cursor:pointer}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-down:hover{background:rgba(0,0,0,.075)}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-down:hover:after{border-top-color:rgba(0,0,0,.5)}.vue-number-input__wrapper .vue-number-input-arrows .vue-number-input-arrows__arrow-down:after{content:\"\";display:block;border-top:6px solid rgba(0,0,0,.6);border-left:4px solid transparent;border-right:4px solid transparent;width:0}",
    map: undefined,
    media: undefined
  });
};
/* scoped */


var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject SSR */

var Component = __vue_normalize__({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, __vue_create_injector__, undefined);

export default Component;
